@@ -63,15 +63,19 @@ _DEFAULT_NAME = "Qwiic Button"
 # Some devices have  multiple available addresses - this is a list of these addresses.
 # NOTE: The first address in this list is considered the default I2C address for the 
 # device.
-_AVAILABLE_I2C_ADDRESS = [0x6F]
+_QWIIC_BUTTON_DEFAULT_ADDRESS = 0x6F
+_FULL_ADDRESS_LIST = list(range(0x08, 0x77+1))  # Full address list (excluding reserved addresses)
+_FULL_ADDRESS_LIST.remove(_QWIIC_BUTTON_DEFAULT_ADDRESS >> 1)   # Remove default address from list
+_AVAILABLE_I2C_ADDRESS = [_QWIIC_BUTTON_DEFAULT_ADDRESS]    # Initialize with default address
+_AVAILABLE_I2C_ADDRESS.extend(_FULL_ADDRESS_LIST) # Add full range of I2C addresses
 
 # Define the class that encapsulates the device being created. All information associated 
 # with this device is encapsulated by this class. The device class should be the only value
 # exported from this module.
 
-class Qwiic_Button(object):
+class QwiicButton(object):
     """"
-    Qwiic_Button
+    QwiicButton
         
         :param address: The I2C address to use for the device.
                         If not provided, the default address is used.
@@ -469,7 +473,8 @@ class Qwiic_Button(object):
         # First, read the PRESSED_QUEUE_STATUS register
         pressed_queue_stat = self._i2c.readByte(self.address, self.PRESSED_QUEUE_STATUS)
         # Convert to binary and clear all bits but isFull
-        self.pressed_is_full = int(pressed_queue_stat) & ~(0xFE)
+        self.pressed_is_full = int(pressed_queue_stat) & ~(0xFB)
+        self.pressed_is_full = self.pressed_is_full >> 2
         # Return pressed_is_full as a bool
         return bool(self.pressed_is_full)
     
@@ -550,7 +555,7 @@ class Qwiic_Button(object):
         pressed_queue_stat = self._i2c.readByte(self.address, self.PRESSED_QUEUE_STATUS)
         self.pressed_pop_request = 1
         # Set pop_request bit to 1
-        pressed_queue_stat = pressed_queue_stat | (self.pressed_pop_request << 2)
+        pressed_queue_stat = pressed_queue_stat | (self.pressed_pop_request)
         self._i2c.writeByte(self.address, self.PRESSED_QUEUE_STATUS, pressed_queue_stat)
         return temp_data
     
@@ -569,7 +574,8 @@ class Qwiic_Button(object):
         # First, read the CLICKED_QUEUE_STATUS register
         clicked_queue_stat = self._i2c.readByte(self.address, self.CLICKED_QUEUE_STATUS)
         # Convert to binary and clear all bits but clicked_is_full
-        self.clicked_is_full = int(clicked_queue_stat) & ~(0xFE)
+        self.clicked_is_full = int(clicked_queue_stat) & ~(0xFB)
+        self.clicked_is_full = self.clicked_is_full >> 2
         # Return clicked_is_full as a bool
         return bool(self.clicked_is_full)
     
@@ -650,7 +656,7 @@ class Qwiic_Button(object):
         clicked_queue_stat = self._i2c.readByte(self.address, self.CLICKED_QUEUE_STATUS)
         self.clicked_pop_request = 1
         # Set pop_request bit to 1
-        clicked_queue_stat = clicked_queue_stat | (self.clicked_pop_request << 2)
+        clicked_queue_stat = clicked_queue_stat | (self.clicked_pop_request)
         self._i2c.writeByte(self.address, self.CLICKED_QUEUE_STATUS, clicked_queue_stat)
         return temp_data
 
